@@ -31,14 +31,10 @@ except ImportError:
 
 from pyresample.geometry import AreaDefinition, CoordinateDefinition
 
-if TYPE_CHECKING:
-    # defined in typeshed to hide private C-level type
-    from hashlib import _Hash
-
 logger = logging.getLogger(__name__)
 
 
-def hash_dict(the_dict: dict, existing_hash: Optional[_Hash] = None) -> _Hash:
+def hash_dict(the_dict: dict, existing_hash: Optional[hashlib._Hash] = None) -> hashlib._Hash:
     """Calculate a hash for a dictionary and optionally update an existing hash."""
     if existing_hash is None:
         existing_hash = hashlib.sha1()  # nosec: B324
